# frozen_string_literal: true

#
# Cookbook:: snu_nginx_fips
# Library:: resource/snu_nginx_fips_service_systemd
#
# Copyright:: 2017, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'chef/platform/service_helpers'
require 'chef/resource'

class Chef
  class Resource
    #
    # An implementation of the snu_nginx_fips_service resource for platforms
    # with Systemd.
    #
    class SnuNginxFipsServiceSystemd < SnuNginxFipsService
      provides :snu_nginx_fips_service_systemd
      provides :snu_nginx_fips_service do |_node|
        Chef::Platform::ServiceHelpers.service_resource_providers
                                      .include?(:systemd)
      end

      #
      # The :create action needs to define a Systemd unit file for Nginx.
      #
      action :create do
        systemd_unit 'nginx.service' do
          content(
            Unit: {
              Description: 'The Nginx web server',
              Documentation: 'http://nginx.org/en/docs/',
              After: 'network-online.target remote-fs.target nss-lookup.target',
              Wants: 'network-online.target'
            },
            Service: {
              Type: 'forking',
              LimitNOFILE: new_resource.file_limit,
              PIDFile: '/run/nginx.pid',
              ExecStart: "/usr/sbin/nginx -c #{new_resource.config_file}",
              ExecReload: '/bin/kill -s HUP $MAINPID',
              ExecStop: '/bin/kill -s TERM $MAINPID'
            },
            Install: {
              WantedBy: 'multi-user.target'
            }
          )
          action :create
        end
      end

      #
      # The :remove action needs to delete the Systemd unit file for Nginx.
      #
      action :remove do
        systemd_unit('nginx.service') { action :delete }
      end
    end
  end
end
